@@ -66,9 +66,9 @@
 compute_dist_matrix = function(traits_table, metric = "gower", center = FALSE,
                                scale = FALSE) {
 
-  if (is.null(rownames(traits_table)) ||
-      rownames(traits_table) == as.character(seq_len(
-        nrow(traits_table)))) {
+  if (is.null(rownames(traits_table)) |
+      identical(rownames(traits_table), as.character(seq_len(
+        nrow(traits_table))))) {
     warning("No row names provided in trait table\n",
             "Distinctiveness and scarcity won't be computable")
   }
