@@ -4,9 +4,17 @@
 #' returns a relative abundance matrix (proportion of individuals of a given species
 #' at a given site). This function works also with sparse matrices.
 #'
-#' @param abund_matrix abundance matrix, with sites in rows and species in columns
+#' @param abund_matrix abundance matrix, with sites in rows and species in
+#'                     columns.
 #'
-#' @seealso \code{\link[funrar]{make_absolute}} for the reverse operation
+#' @examples
+#' data("aravo", package = "ade4")
+#'
+#' # Site-species matrix
+#' mat = as.matrix(aravo$spe)
+#' head(mat)[, 1:5]  # Has absolute abundances
+#' rel_mat = make_relative(mat)
+#' head(rel_mat)  # Relative abundances
 #'
 #' @export
 make_relative = function(abund_matrix) {
@@ -32,43 +40,11 @@ make_relative = function(abund_matrix) {
   return(rel_abund_matrix)
 }
 
-#' Abundance matrix from relative abundances matrix
-#'
-#' Convert the input relative abundances matrix to an abundance matrix
-#'
-#' @param rel_abund_matrix a relative abundance matrix (proportion of individuals
-#'                         of a given species at a given site)
-#'
-#' @seealso \code{\link[funrar]{make_relative}} for the reverse operation
-#'
-#' @export
-make_absolute = function(rel_abund_matrix) {
-
-  # Compute absolute matrix
-  if (requireNamespace("Matrix", quietly = TRUE) &
-      is(rel_abund_matrix, "sparseMatrix")) {
-
-    sites_abund = Matrix::rowSums((rel_abund_matrix != 0) &
-                                    (!is.na(rel_abund_matrix)), na.rm = TRUE)
-
-    abs_matrix = rel_abund_matrix * sites_abund
-  } else {
-    # Compute total site abundances
-    sites_abund = rowSums((rel_abund_matrix != 0) &
-                            (!is.na(rel_abund_matrix)), na.rm = TRUE)
-
-    # Divide each individual abundace by total site abundance
-    abs_matrix = sweep(rel_abund_matrix, 1, sites_abund, "*")
-  }
-
-  return(abs_matrix)
-}
-
 #' Tell if matrix or data.frame has relative abundances
 #'
 #' From an abundance/presence-absence matrix or data.frame tells if it contains
 #' relative abundances or absolute abundances. Checks if all abundances are
-#' between 1 and 0 but \strong{never checks sum of abundances per community}.
+#' between 1 and 0 but **never checks sum of abundances per community**.
 #'
 #' @param given_obj abundance or presence-absence matrix, with sites in rows and
 #'                  species in columns, or tidy community data frame
@@ -76,8 +52,21 @@ make_absolute = function(rel_abund_matrix) {
 #' @param abund name of the column of the provided object that contains the
 #'              abundances
 #'
-#' @seealso \code{\link[funrar]{make_relative}} to transform matrix into a
-#'   relative abundance matrix.
+#' @seealso [make_relative()] to transform matrix into a relative abundance
+#'          matrix.
+#'
+#' @examples
+#' data("aravo", package = "ade4")
+#'
+#' # Site-species matrix
+#' mat = as.matrix(aravo$spe)
+#' head(mat)[, 1:5]  # Has absolute abundances
+#' rel_mat = make_relative(mat)
+#' head(rel_mat)  # Relative abundances
+#'
+#' # Forced to use ':::' becasue function is not exported
+#' funrar:::is_relative(mat)      # FALSE
+#' funrar:::is_relative(rel_mat)  # TRUE
 #'
 #' @importFrom stats na.omit
 is_relative = function(given_obj, abund = NULL) {
